import { notFound } from 'next/navigation';
import Link from 'next/link';
import { Clock, Dumbbell, ArrowLeft } from 'lucide-react';
import { workouts } from '@/data/workouts';

export function generateStaticParams() {
  return workouts.map((workout) => ({
    id: workout.id,
  }));
}

export default async function WorkoutPage({ params }: { params: Promise<{ id: string }> }) {
  const { id } = await params;
  const workout = workouts.find(w => w.id === id);

  if (!workout) {
    notFound();
  }

  const difficultyColors = {
    recovery: 'var(--sage-300)',
    easy: 'var(--sage-400)',
    moderate: 'var(--pink-300)',
    strenuous: 'var(--pink-400)'
  };

  return (
    <div className="container">
      <Link href="/workouts" className="back-link">
        <ArrowLeft size={16} />
        Back to all workouts
      </Link>

      <section className="intro">
        <h1>{workout.title}</h1>
        
        {workout.description && <p>{workout.description}</p>}
        
        <div style={{ display: 'flex', gap: 'var(--space-xl)', marginTop: 'var(--space-md)' }}>
          <span style={{ 
            display: 'inline-flex', 
            alignItems: 'center', 
            gap: 'var(--space-xs)',
            color: difficultyColors[workout.difficulty],
            fontWeight: 500
          }}>
            <Dumbbell size={20} />
            {workout.difficulty.charAt(0).toUpperCase() + workout.difficulty.slice(1)}
          </span>
          <span style={{ 
            display: 'inline-flex', 
            alignItems: 'center', 
            gap: 'var(--space-xs)',
            fontWeight: 500
          }}>
            <Clock size={20} />
            {workout.duration} minutes
          </span>
        </div>
      </section>

      <section className="resume-section">
        <h2>Exercises</h2>
        <ul className="bullet-list">
          {workout.exercises.map((exercise, index) => (
            <li key={index}>{exercise}</li>
          ))}
        </ul>
      </section>
    </div>
  );
}