'use client';

import { useState } from 'react';
import type { Metadata } from 'next';
import { WorkoutCard } from '@/components/WorkoutCard/WorkoutCard';
import { WorkoutFilters } from '@/components/WorkoutFilters/WorkoutFilters';
import { workouts } from '@/data/workouts';
import { WorkoutDifficulty, WorkoutDuration } from '@/types';

export default function WorkoutsPage() {
  const [selectedDifficulty, setSelectedDifficulty] = useState<WorkoutDifficulty | null>(null);
  const [selectedDuration, setSelectedDuration] = useState<WorkoutDuration | null>(null);

  const filteredWorkouts = workouts.filter(workout => {
    if (selectedDifficulty && workout.difficulty !== selectedDifficulty) {
      return false;
    }
    if (selectedDuration && workout.duration !== selectedDuration) {
      return false;
    }
    return true;
  });

  return (
    <div className="container">
      <section className="intro">
        <h1>Uphill Fitness</h1>
        <p>A collection of workouts I use to improve my mountaineering fitness</p>
      </section>

      <section className="projects">
        <h2>Workouts</h2>
        
        <WorkoutFilters
          selectedDifficulty={selectedDifficulty}
          selectedDuration={selectedDuration}
          onDifficultyChange={setSelectedDifficulty}
          onDurationChange={setSelectedDuration}
        />

        <div className="project-grid">
          {filteredWorkouts.map((workout) => (
            <WorkoutCard key={workout.id} workout={workout} />
          ))}
        </div>

        {filteredWorkouts.length === 0 && (
          <p style={{ textAlign: 'center', color: 'var(--accent-secondary)', marginTop: 'var(--space-xl)' }}>
            No workouts found matching your criteria. Try adjusting your filters.
          </p>
        )}
      </section>
    </div>
  );
}