'use client';

import { WorkoutDifficulty, WorkoutDuration } from '@/types';

interface WorkoutFiltersProps {
  selectedDifficulty: WorkoutDifficulty | null;
  selectedDuration: WorkoutDuration | null;
  onDifficultyChange: (difficulty: WorkoutDifficulty | null) => void;
  onDurationChange: (duration: WorkoutDuration | null) => void;
}

export function WorkoutFilters({ 
  selectedDifficulty, 
  selectedDuration, 
  onDifficultyChange, 
  onDurationChange 
}: WorkoutFiltersProps) {
  const difficulties: WorkoutDifficulty[] = ['recovery', 'easy', 'moderate', 'strenuous'];
  const durations: WorkoutDuration[] = [30, 60, 90, 120, 150, 180, 210, 240, 270, 300];

  return (
    <div className="filters-container">
      <div className="filter-group">
        <label htmlFor="difficulty-filter">Difficulty:</label>
        <select
          id="difficulty-filter"
          value={selectedDifficulty || ''}
          onChange={(e) => onDifficultyChange(e.target.value ? e.target.value as WorkoutDifficulty : null)}
          className="filter-select"
        >
          <option value="">All difficulties</option>
          {difficulties.map(diff => (
            <option key={diff} value={diff}>
              {diff.charAt(0).toUpperCase() + diff.slice(1)}
            </option>
          ))}
        </select>
      </div>

      <div className="filter-group">
        <label htmlFor="duration-filter">Duration:</label>
        <select
          id="duration-filter"
          value={selectedDuration || ''}
          onChange={(e) => onDurationChange(e.target.value ? Number(e.target.value) as WorkoutDuration : null)}
          className="filter-select"
        >
          <option value="">All durations</option>
          {durations.map(duration => (
            <option key={duration} value={duration}>
              {duration} minutes
            </option>
          ))}
        </select>
      </div>
    </div>
  );
}